@@ -9,6 +9,7 @@
 #'   If `FALSE`, shows for each node a matrix with nodal types as rows and
 #'   parent types as columns, if applicable. Defaults to `TRUE`.
 #' @keywords internal
+#' @noRd
 #' @importFrom rlang is_empty
 #' @return A named \code{list} of nodal types for each parent in a DAG
 
@@ -42,7 +43,7 @@ get_nodal_types <- function(model, collapse = TRUE) {
   }
 
   attr(nodal_types, "interpret") <- interpret_type(model)
-  class(nodal_types) <- c("nodal_types", "list")
+  class(nodal_types) <- "list"
 
   return(nodal_types)
 }
@@ -52,6 +53,7 @@ get_nodal_types <- function(model, collapse = TRUE) {
 #' @param nodal_types A list of nodal types in collapsed form ('01', '11') etc..
 #' @return A \code{list} containing nodes with nodal types in data.frame form
 #' @keywords internal
+#' @noRd
 
 uncollapse_nodal_types <- function(nodal_types) {
   x <- nodal_types |>
@@ -74,11 +76,11 @@ uncollapse_nodal_types <- function(nodal_types) {
     # Add row names
     rownames(x[[j]]) <- apply(x[[j]], 1, paste, collapse = "")
     # Add col names
-    colnames(x[[j]]) <- perm(rep(1, log(ncol(x[[j]]), 2))) %>%
+    colnames(x[[j]]) <- perm(rep(1, log(ncol(x[[j]]), 2))) |>
       apply(1, paste, collapse = "")
   }
 
-  class(x) <- c("nodal_types", "list")
+  class(x) <- c("list")
 
   return(x)
 }
@@ -91,6 +93,7 @@ uncollapse_nodal_types <- function(nodal_types) {
 #'   otherwise returns 0, 1. Defaults to `FALSE`
 #' @return A named list containing nodal types for each node
 #' @keywords internal
+#' @noRd
 #' @examples
 #' \donttest{
 #' model <- make_model('X -> K -> Y')
@@ -122,7 +125,7 @@ make_nodal_types <- function(model,
   })
 
   names(nodal_types) <- nodes
-  class(nodal_types) <- c("nodal_types", "list")
+  class(nodal_types) <- "list"
 
  return(nodal_types)
 }
@@ -133,10 +136,11 @@ make_nodal_types <- function(model,
 #'   otherwise returns 0, 1
 #' @return A \code{list} containing nodes with nodal types in a vector form.
 #' @keywords internal
+#' @noRd
 #' @examples
 #'
 #' model <- make_model('X -> K -> Y')
-#' (nodal_types <- grab(model, "nodal_types", collapse = FALSE))
+#' (nodal_types <- inspect(model, "nodal_types"))
 #' CausalQueries:::collapse_nodal_types(nodal_types )
 collapse_nodal_types <- function(nodal_types,
                                  include_node_names = FALSE) {
@@ -156,7 +160,7 @@ collapse_nodal_types <- function(nodal_types,
       paste0(labels)
     })
     names(types) <- names(nodal_types)
-    class(types) <- c("nodal_types", "list")
+    class(types) <- "list"
 
     return(types)
   }
@@ -167,6 +171,7 @@ collapse_nodal_types <- function(nodal_types,
 #' @return A \code{data.frame} whose rows contain digits of
 #'   each causal types in a model
 #' @keywords internal
+#' @noRd
 #' @examples
 #' \donttest{
 #' CausalQueries:::type_matrix(2)
@@ -182,3 +187,4 @@ type_matrix <- function(parent_n) {
   colnames(type_mat) <- labels
   return(type_mat)
 }
+
