@@ -223,20 +223,18 @@ set_priors <- function(model,
 #' @rdname prior_setting
 #'
 #' @param model A model object generated by make_model().
+#' @param nodes a vector of nodes
 #' @return A vector indicating the hyperparameters of the prior distribution
 #'   of the nodal types.
-#' @export
 #' @family priors
-#' @examples
-#'
-#' # get_priors examples:
-#'
-#' get_priors(make_model('X -> Y'))
 
-get_priors <- function(model) {
+get_priors <- function(model, nodes = NULL) {
+
+  if(!all(nodes %in% model$nodes)) stop("Indicated node is not in model")
 
     x <- model$parameters_df$priors
     names(x) <- model$parameters_df$param_names
+    if(!is.null(nodes)) x <- x[model$parameters_df$node %in% nodes]
     return(x)
 
 }
